.. _upoints-label:

``upoints``
===========

.. warning::

   At this point ``upoints`` only exists to assist the users who have been using
   it for years, I *absolutely* do **not** recommend its use to new users.

:mod:`upoints` is a collection of `GPL v3`_ licensed modules for working
with points on Earth, or other near spherical objects.  It allows you to
calculate the distance and bearings between points, mangle
xearth_/xplanet_ data files, work with online UK trigpoint databases,
NOAA_'s weather station database and other such location databases.

Previous versions of :mod:`upoints` were called ``earth_distance``, but
the name was changed as it no longer reflected the majority of uses the
packages was targeted at.

Contents
--------

.. toctree::
   :maxdepth: 2

   geolocation_and_pathcross
   merlin
   python_cities
   pythons_on_a_plane
   trigpointing_and_point_py
   xearth_and_pathcross

   edist.1
   api/index

   glossary
   release
   todo

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _GPL v3: http://www.gnu.org/licenses/
.. _xearth: http://hewgill.com/xearth/original/
.. _xplanet: http://xplanet.sourceforge.net/
.. _NOAA: http://weather.noaa.gov/
